@@ -12,6 +12,7 @@ import (
 	"strings"
 
 	"github.com/derailed/k9s/internal/client"
+	"github.com/derailed/k9s/internal/model1"
 	"github.com/derailed/tcell/v2"
 	"github.com/derailed/tview"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -33,33 +34,34 @@ type Benchmark struct {
 }
 
 // ColorerFunc colors a resource row.
-func (b Benchmark) ColorerFunc() ColorerFunc {
-	return func(ns string, h Header, re RowEvent) tcell.Color {
-		if !Happy(ns, h, re.Row) {
-			return ErrColor
+func (b Benchmark) ColorerFunc() model1.ColorerFunc {
+	return func(ns string, h model1.Header, re *model1.RowEvent) tcell.Color {
+		if !model1.IsValid(ns, h, re.Row) {
+			return model1.ErrColor
 		}
+
 		return tcell.ColorPaleGreen
 	}
 }
 
 // Header returns a header row.
-func (Benchmark) Header(ns string) Header {
-	return Header{
-		HeaderColumn{Name: "NAMESPACE"},
-		HeaderColumn{Name: "NAME"},
-		HeaderColumn{Name: "STATUS"},
-		HeaderColumn{Name: "TIME"},
-		HeaderColumn{Name: "REQ/S", Align: tview.AlignRight},
-		HeaderColumn{Name: "2XX", Align: tview.AlignRight},
-		HeaderColumn{Name: "4XX/5XX", Align: tview.AlignRight},
-		HeaderColumn{Name: "REPORT"},
-		HeaderColumn{Name: "VALID", Wide: true},
-		HeaderColumn{Name: "AGE", Time: true},
+func (Benchmark) Header(ns string) model1.Header {
+	return model1.Header{
+		model1.HeaderColumn{Name: "NAMESPACE"},
+		model1.HeaderColumn{Name: "NAME"},
+		model1.HeaderColumn{Name: "STATUS"},
+		model1.HeaderColumn{Name: "TIME"},
+		model1.HeaderColumn{Name: "REQ/S", Align: tview.AlignRight},
+		model1.HeaderColumn{Name: "2XX", Align: tview.AlignRight},
+		model1.HeaderColumn{Name: "4XX/5XX", Align: tview.AlignRight},
+		model1.HeaderColumn{Name: "REPORT"},
+		model1.HeaderColumn{Name: "VALID", Wide: true},
+		model1.HeaderColumn{Name: "AGE", Time: true},
 	}
 }
 
 // Render renders a K8s resource to screen.
-func (b Benchmark) Render(o interface{}, ns string, r *Row) error {
+func (b Benchmark) Render(o interface{}, ns string, r *model1.Row) error {
 	bench, ok := o.(BenchInfo)
 	if !ok {
 		return fmt.Errorf("no benchmarks available %T", o)
@@ -71,7 +73,7 @@ func (b Benchmark) Render(o interface{}, ns string, r *Row) error {
 	}
 
 	r.ID = bench.Path
-	r.Fields = make(Fields, len(b.Header(ns)))
+	r.Fields = make(model1.Fields, len(b.Header(ns)))
 	if err := b.initRow(r.Fields, bench.File); err != nil {
 		return err
 	}
@@ -82,7 +84,7 @@ func (b Benchmark) Render(o interface{}, ns string, r *Row) error {
 }
 
 // Happy returns true if resource is happy, false otherwise.
-func (Benchmark) diagnose(ns string, ff Fields) error {
+func (Benchmark) diagnose(ns string, ff model1.Fields) error {
 	statusCol := 3
 	if !client.IsAllNamespaces(ns) {
 		statusCol--
@@ -109,7 +111,7 @@ func (Benchmark) readFile(file string) (string, error) {
 	return string(data), nil
 }
 
-func (b Benchmark) initRow(row Fields, f os.FileInfo) error {
+func (b Benchmark) initRow(row model1.Fields, f os.FileInfo) error {
 	tokens := strings.Split(f.Name(), "_")
 	if len(tokens) < 2 {
 		return fmt.Errorf("invalid file name %s", f.Name())
@@ -122,7 +124,7 @@ func (b Benchmark) initRow(row Fields, f os.FileInfo) error {
 	return nil
 }
 
-func (b Benchmark) augmentRow(fields Fields, data string) {
+func (b Benchmark) augmentRow(fields model1.Fields, data string) {
 	if len(data) == 0 {
 		return
 	}
