@@ -4,91 +4,57 @@
 package render
 
 import (
-	"math"
+	"encoding/json"
+	"fmt"
+	"os"
 	"testing"
 	"time"
 
 	"github.com/derailed/k9s/internal/client"
+	"github.com/derailed/k9s/internal/model1"
 	"github.com/stretchr/testify/assert"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
+	metav1beta1 "k8s.io/apimachinery/pkg/apis/meta/v1beta1"
+	"k8s.io/apimachinery/pkg/runtime"
 )
 
-func TestSortLabels(t *testing.T) {
-	uu := map[string]struct {
-		labels string
-		e      [][]string
-	}{
-		"simple": {
-			labels: "a=b,c=d",
-			e: [][]string{
-				{"a", "c"},
-				{"b", "d"},
+func TestTableGenericHydrate(t *testing.T) {
+	raw := raw(t, "p1")
+	tt := metav1beta1.Table{
+		ColumnDefinitions: []metav1beta1.TableColumnDefinition{
+			{Name: "c1"},
+			{Name: "c2"},
+		},
+		Rows: []metav1beta1.TableRow{
+			{
+				Cells:  []interface{}{"fred", 10},
+				Object: runtime.RawExtension{Raw: raw},
+			},
+			{
+				Cells:  []interface{}{"blee", 20},
+				Object: runtime.RawExtension{Raw: raw},
 			},
 		},
 	}
+	rr := make([]model1.Row, 2)
+	var re Generic
+	re.SetTable("blee", &tt)
 
-	for k := range uu {
-		u := uu[k]
-		t.Run(k, func(t *testing.T) {
-			hh, vv := sortLabels(labelize(u.labels))
-			assert.Equal(t, u.e[0], hh)
-			assert.Equal(t, u.e[1], vv)
-		})
-	}
+	assert.Nil(t, model1.GenericHydrate("blee", &tt, rr, &re))
+	assert.Equal(t, 2, len(rr))
+	assert.Equal(t, 3, len(rr[0].Fields))
 }
 
-func TestLabelize(t *testing.T) {
-	uu := map[string]struct {
-		labels string
-		e      map[string]string
-	}{
-		"simple": {
-			labels: "a=b,c=d",
-			e:      map[string]string{"a": "b", "c": "d"},
-		},
+func TestTableHydrate(t *testing.T) {
+	oo := []runtime.Object{
+		&PodWithMetrics{Raw: load(t, "p1")},
 	}
+	rr := make([]model1.Row, 1)
 
-	for k := range uu {
-		u := uu[k]
-		t.Run(k, func(t *testing.T) {
-			assert.Equal(t, u.e, labelize(u.labels))
-		})
-	}
-}
-
-func TestDurationToSecond(t *testing.T) {
-	uu := map[string]struct {
-		s string
-		e int64
-	}{
-		"seconds":                 {s: "22s", e: 22},
-		"minutes":                 {s: "22m", e: 1320},
-		"hours":                   {s: "12h", e: 43200},
-		"days":                    {s: "3d", e: 259200},
-		"day_hour":                {s: "3d9h", e: 291600},
-		"day_hour_minute":         {s: "2d22h3m", e: 252180},
-		"day_hour_minute_seconds": {s: "2d22h3m50s", e: 252230},
-		"year":                    {s: "3y", e: 94608000},
-		"year_day":                {s: "1y2d", e: 31708800},
-		"n/a":                     {s: NAValue, e: math.MaxInt64},
-	}
-
-	for k := range uu {
-		u := uu[k]
-		t.Run(k, func(t *testing.T) {
-			assert.Equal(t, u.e, durationToSeconds(u.s))
-		})
-	}
-}
-
-func BenchmarkDurationToSecond(b *testing.B) {
-	t := "2d22h3m50s"
-
-	b.ReportAllocs()
-	b.ResetTimer()
-	for n := 0; n < b.N; n++ {
-		durationToSeconds(t)
-	}
+	assert.Nil(t, model1.Hydrate("blee", oo, rr, Pod{}))
+	assert.Equal(t, 1, len(rr))
+	assert.Equal(t, 23, len(rr[0].Fields))
 }
 
 func TestToAge(t *testing.T) {
@@ -308,34 +274,6 @@ func TestBlank(t *testing.T) {
 	}
 }
 
-func TestIn(t *testing.T) {
-	uu := map[string]struct {
-		a []string
-		v string
-		e bool
-	}{
-		"in": {
-			a: []string{"fred", "blee"},
-			v: "blee",
-			e: true,
-		},
-		"empty": {
-			v: "blee",
-		},
-		"missing": {
-			a: []string{"fred", "blee"},
-			v: "duh",
-		},
-	}
-
-	for k := range uu {
-		uc := uu[k]
-		t.Run(k, func(t *testing.T) {
-			assert.Equal(t, uc.e, in(uc.a, uc.v))
-		})
-	}
-}
-
 func TestMetaFQN(t *testing.T) {
 	uu := map[string]struct {
 		m metav1.ObjectMeta
@@ -489,3 +427,20 @@ func BenchmarkIntToStr(b *testing.B) {
 		IntToStr(v)
 	}
 }
+
+// Helpers...
+
+func load(t *testing.T, n string) *unstructured.Unstructured {
+	raw, err := os.ReadFile(fmt.Sprintf("testdata/%s.json", n))
+	assert.Nil(t, err)
+	var o unstructured.Unstructured
+	err = json.Unmarshal(raw, &o)
+	assert.Nil(t, err)
+	return &o
+}
+
+func raw(t *testing.T, n string) []byte {
+	raw, err := os.ReadFile(fmt.Sprintf("testdata/%s.json", n))
+	assert.Nil(t, err)
+	return raw
+}
