@@ -40,8 +40,8 @@ func NewDeploy(gvr client.GVR) ResourceViewer {
 	return &d
 }
 
-func (d *Deploy) bindKeys(aa ui.KeyActions) {
-	aa.Add(ui.KeyActions{
+func (d *Deploy) bindKeys(aa *ui.KeyActions) {
+	aa.Bulk(ui.KeyMap{
 		ui.KeyShiftR: ui.NewKeyAction("Sort Ready", d.GetTable().SortColCmd(readyCol, true), false),
 		ui.KeyShiftU: ui.NewKeyAction("Sort UpToDate", d.GetTable().SortColCmd(uptodateCol, true), false),
 		ui.KeyShiftL: ui.NewKeyAction("Sort Available", d.GetTable().SortColCmd(availCol, true), false),
