@@ -7,6 +7,7 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"io/fs"
 	"os"
 	"strings"
 
@@ -14,6 +15,7 @@ import (
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/dao"
 	"github.com/derailed/k9s/internal/model"
+	"github.com/derailed/k9s/internal/model1"
 	"github.com/derailed/k9s/internal/render"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/k9s/internal/ui/dialog"
@@ -28,12 +30,14 @@ import (
 )
 
 const (
-	windowsOS      = "windows"
-	powerShell     = "powershell"
-	osSelector     = "kubernetes.io/os"
-	osBetaSelector = "beta." + osSelector
-	trUpload       = "Upload"
-	trDownload     = "Download"
+	windowsOS        = "windows"
+	powerShell       = "powershell"
+	osSelector       = "kubernetes.io/os"
+	osBetaSelector   = "beta." + osSelector
+	trUpload         = "Upload"
+	trDownload       = "Download"
+	pfIndicator      = "[orange::b]Ⓕ"
+	defaultTxRetries = 999
 )
 
 // Pod represents a pod viewer.
@@ -58,20 +62,25 @@ func NewPod(gvr client.GVR) ResourceViewer {
 	return &p
 }
 
-func (p *Pod) portForwardIndicator(data *render.TableData) {
+func (p *Pod) portForwardIndicator(data *model1.TableData) {
 	ff := p.App().factory.Forwarders()
 
-	col := data.IndexOfHeader("PF")
-	for _, re := range data.RowEvents {
-		if ff.IsPodForwarded(re.Row.ID) {
-			re.Row.Fields[col] = "[orange::b]Ⓕ"
-		}
+	defer decorateCpuMemHeaderRows(p.App(), data)
+	idx, ok := data.IndexOfHeader("PF")
+	if !ok {
+		return
 	}
-	decorateCpuMemHeaderRows(p.App(), data)
+
+	data.RowsRange(func(_ int, re model1.RowEvent) bool {
+		if ff.IsPodForwarded(re.Row.ID) {
+			re.Row.Fields[idx] = pfIndicator
+		}
+		return true
+	})
 }
 
-func (p *Pod) bindDangerousKeys(aa ui.KeyActions) {
-	aa.Add(ui.KeyActions{
+func (p *Pod) bindDangerousKeys(aa *ui.KeyActions) {
+	aa.Bulk(ui.KeyMap{
 		tcell.KeyCtrlK: ui.NewKeyActionWithOpts(
 			"Kill",
 			p.killCmd,
@@ -110,12 +119,12 @@ func (p *Pod) bindDangerousKeys(aa ui.KeyActions) {
 	})
 }
 
-func (p *Pod) bindKeys(aa ui.KeyActions) {
+func (p *Pod) bindKeys(aa *ui.KeyActions) {
 	if !p.App().Config.K9s.IsReadOnly() {
 		p.bindDangerousKeys(aa)
 	}
 
-	aa.Add(ui.KeyActions{
+	aa.Bulk(ui.KeyMap{
 		ui.KeyO:      ui.NewKeyAction("Show Node", p.showNode, true),
 		ui.KeyShiftR: ui.NewKeyAction("Sort Ready", p.GetTable().SortColCmd(readyCol, true), false),
 		ui.KeyShiftT: ui.NewKeyAction("Sort Restart", p.GetTable().SortColCmd("RESTARTS", false), false),
@@ -123,7 +132,7 @@ func (p *Pod) bindKeys(aa ui.KeyActions) {
 		ui.KeyShiftI: ui.NewKeyAction("Sort IP", p.GetTable().SortColCmd("IP", true), false),
 		ui.KeyShiftO: ui.NewKeyAction("Sort Node", p.GetTable().SortColCmd("NODE", true), false),
 	})
-	aa.Add(resourceSorters(p.GetTable()))
+	aa.Merge(resourceSorters(p.GetTable()))
 }
 
 func (p *Pod) logOptions(prev bool) (*dao.LogOptions, error) {
@@ -302,36 +311,36 @@ func (p *Pod) transferCmd(evt *tcell.EventKey) *tcell.EventKey {
 	}
 
 	ns, n := client.Namespaced(path)
-	ack := func(from, to, co string, download, no_preserve bool) bool {
-		local := to
-		if !download {
-			local = from
+	ack := func(args dialog.TransferArgs) bool {
+		local := args.To
+		if !args.Download {
+			local = args.From
 		}
-		if _, err := os.Stat(local); !download && os.IsNotExist(err) {
+		if _, err := os.Stat(local); !args.Download && errors.Is(err, fs.ErrNotExist) {
 			p.App().Flash().Err(err)
 			return false
 		}
 
-		args := make([]string, 0, 10)
-		args = append(args, "cp")
-		args = append(args, strings.TrimSpace(from))
-		args = append(args, strings.TrimSpace(to))
-		args = append(args, fmt.Sprintf("--no-preserve=%t", no_preserve))
-		if co != "" {
-			args = append(args, "-c="+co)
+		opts := make([]string, 0, 10)
+		opts = append(opts, "cp")
+		opts = append(opts, strings.TrimSpace(args.From))
+		opts = append(opts, strings.TrimSpace(args.To))
+		opts = append(opts, fmt.Sprintf("--no-preserve=%t", args.NoPreserve))
+		if args.CO != "" {
+			opts = append(opts, "-c="+args.CO)
 		}
 
-		opts := shellOpts{
+		cliOpts := shellOpts{
 			background: true,
-			args:       args,
+			args:       opts,
 		}
 		op := trUpload
-		if download {
+		if args.Download {
 			op = trDownload
 		}
 
-		fqn := path + ":" + co
-		if err := runK(p.App(), opts); err != nil {
+		fqn := path + ":" + args.CO
+		if err := runK(p.App(), cliOpts); err != nil {
 			p.App().cowCmd(err.Error())
 		} else {
 			p.App().Flash().Infof("%s successful on %s!", op, fqn)
@@ -351,6 +360,7 @@ func (p *Pod) transferCmd(evt *tcell.EventKey) *tcell.EventKey {
 		Message:    "Download Files",
 		Pod:        fmt.Sprintf("%s/%s:", ns, n),
 		Ack:        ack,
+		Retries:    defaultTxRetries,
 		Cancel:     func() {},
 	}
 	dialog.ShowUploads(p.App().Styles.Dialog(), p.App().Content.Pages, opts)
@@ -555,13 +565,13 @@ func osFromSelector(s map[string]string) (string, bool) {
 	return os, ok
 }
 
-func resourceSorters(t *Table) ui.KeyActions {
-	return ui.KeyActions{
+func resourceSorters(t *Table) *ui.KeyActions {
+	return ui.NewKeyActionsFromMap(ui.KeyMap{
 		ui.KeyShiftC:   ui.NewKeyAction("Sort CPU", t.SortColCmd(cpuCol, false), false),
 		ui.KeyShiftM:   ui.NewKeyAction("Sort MEM", t.SortColCmd(memCol, false), false),
 		ui.KeyShiftX:   ui.NewKeyAction("Sort CPU/R", t.SortColCmd("%CPU/R", false), false),
 		ui.KeyShiftZ:   ui.NewKeyAction("Sort MEM/R", t.SortColCmd("%MEM/R", false), false),
 		tcell.KeyCtrlX: ui.NewKeyAction("Sort CPU/L", t.SortColCmd("%CPU/L", false), false),
 		tcell.KeyCtrlQ: ui.NewKeyAction("Sort MEM/L", t.SortColCmd("%MEM/L", false), false),
-	}
+	})
 }
